==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/AzureDatabricksDeltaLakeImportCommandArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.AzureDatabricksDeltaLakeImportCommandArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Azure Databricks Delta Lake import command settings.
 * @property dateFormat Specify the date format for csv in Azure Databricks Delta Lake Copy. Type: string (or Expression with resultType string).
 * @property timestampFormat Specify the timestamp format for csv in Azure Databricks Delta Lake Copy. Type: string (or Expression with resultType string).
 * @property type The import setting type.
 * Expected value is 'AzureDatabricksDeltaLakeImportCommand'.
 */
public data class AzureDatabricksDeltaLakeImportCommandArgs(
    public val dateFormat: Output<Any>? = null,
    public val timestampFormat: Output<Any>? = null,
    public val type: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.AzureDatabricksDeltaLakeImportCommandArgs> {
    override fun toJava():
        com.pulumi.azurenative.datafactory.inputs.AzureDatabricksDeltaLakeImportCommandArgs =
        com.pulumi.azurenative.datafactory.inputs.AzureDatabricksDeltaLakeImportCommandArgs.builder()
            .dateFormat(dateFormat?.applyValue({ args0 -> args0 }))
            .timestampFormat(timestampFormat?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AzureDatabricksDeltaLakeImportCommandArgs].
 */
@PulumiTagMarker
public class AzureDatabricksDeltaLakeImportCommandArgsBuilder internal constructor() {
    private var dateFormat: Output<Any>? = null

    private var timestampFormat: Output<Any>? = null

    private var type: Output<String>? = null

    /**
     * @param value Specify the date format for csv in Azure Databricks Delta Lake Copy. Type: string (or Expression with resultType string).
     */
    @JvmName("ayvplwrsrgdmwfrv")
    public suspend fun dateFormat(`value`: Output<Any>) {
        this.dateFormat = value
    }

    /**
     * @param value Specify the timestamp format for csv in Azure Databricks Delta Lake Copy. Type: string (or Expression with resultType string).
     */
    @JvmName("qpceequaptqsrfpd")
    public suspend fun timestampFormat(`value`: Output<Any>) {
        this.timestampFormat = value
    }

    /**
     * @param value The import setting type.
     * Expected value is 'AzureDatabricksDeltaLakeImportCommand'.
     */
    @JvmName("dbbekwxjueldodmd")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Specify the date format for csv in Azure Databricks Delta Lake Copy. Type: string (or Expression with resultType string).
     */
    @JvmName("kvstwhdoimmnxxff")
    public suspend fun dateFormat(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dateFormat = mapped
    }

    /**
     * @param value Specify the timestamp format for csv in Azure Databricks Delta Lake Copy. Type: string (or Expression with resultType string).
     */
    @JvmName("nwlmmfixfiiqfrio")
    public suspend fun timestampFormat(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timestampFormat = mapped
    }

    /**
     * @param value The import setting type.
     * Expected value is 'AzureDatabricksDeltaLakeImportCommand'.
     */
    @JvmName("rjoeabhhdvjwsuxh")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): AzureDatabricksDeltaLakeImportCommandArgs =
        AzureDatabricksDeltaLakeImportCommandArgs(
            dateFormat = dateFormat,
            timestampFormat = timestampFormat,
            type = type ?: throw PulumiNullFieldException("type"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/AzureDatabricksDeltaLakeImportCommandArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.AzureDatabricksDeltaLakeImportCommandArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Azure Databricks Delta Lake import command settings.
 * @property dateFormat Specify the date format for csv in Azure Databricks Delta Lake Copy. Type: string (or Expression with resultType string).
 * @property timestampFormat Specify the timestamp format for csv in Azure Databricks Delta Lake Copy. Type: string (or Expression with resultType string).
 * @property type The import setting type.
 * Expected value is 'AzureDatabricksDeltaLakeImportCommand'.
 */
public data class AzureDatabricksDeltaLakeImportCommandArgs(
    public val dateFormat: Output<Any>? = null,
    public val timestampFormat: Output<Any>? = null,
    public val type: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.AzureDatabricksDeltaLakeImportCommandArgs> {
    override fun toJava():
        com.pulumi.azurenative.datafactory.inputs.AzureDatabricksDeltaLakeImportCommandArgs =
        com.pulumi.azurenative.datafactory.inputs.AzureDatabricksDeltaLakeImportCommandArgs.builder()
            .dateFormat(dateFormat?.applyValue({ args0 -> args0 }))
            .timestampFormat(timestampFormat?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AzureDatabricksDeltaLakeImportCommandArgs].
 */
@PulumiTagMarker
public class AzureDatabricksDeltaLakeImportCommandArgsBuilder internal constructor() {
    private var dateFormat: Output<Any>? = null

    private var timestampFormat: Output<Any>? = null

    private var type: Output<String>? = null

    /**
     * @param value Specify the date format for csv in Azure Databricks Delta Lake Copy. Type: string (or Expression with resultType string).
     */
    @JvmName("rufaqbkpsjktattm")
    public suspend fun dateFormat(`value`: Output<Any>) {
        this.dateFormat = value
    }

    /**
     * @param value Specify the timestamp format for csv in Azure Databricks Delta Lake Copy. Type: string (or Expression with resultType string).
     */
    @JvmName("xprkkdabtdaddjhr")
    public suspend fun timestampFormat(`value`: Output<Any>) {
        this.timestampFormat = value
    }

    /**
     * @param value The import setting type.
     * Expected value is 'AzureDatabricksDeltaLakeImportCommand'.
     */
    @JvmName("ocnuqvxyrwwmbacm")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Specify the date format for csv in Azure Databricks Delta Lake Copy. Type: string (or Expression with resultType string).
     */
    @JvmName("trhmlhmsqijeugof")
    public suspend fun dateFormat(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dateFormat = mapped
    }

    /**
     * @param value Specify the timestamp format for csv in Azure Databricks Delta Lake Copy. Type: string (or Expression with resultType string).
     */
    @JvmName("iponlxwedkisqosa")
    public suspend fun timestampFormat(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timestampFormat = mapped
    }

    /**
     * @param value The import setting type.
     * Expected value is 'AzureDatabricksDeltaLakeImportCommand'.
     */
    @JvmName("xxswdxjykitnjkcn")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): AzureDatabricksDeltaLakeImportCommandArgs =
        AzureDatabricksDeltaLakeImportCommandArgs(
            dateFormat = dateFormat,
            timestampFormat = timestampFormat,
            type = type ?: throw PulumiNullFieldException("type"),
        )
}
